<?php
/*
Plugin Name: Easy Banner Link
Plugin URI: https://inexio.jp/results/inx-easy-banner-link/
Description: 簡易的にバナー画像リンクを管理します
Version: 1.0.21
Author: inexio
Author URI: https://inexio.jp
Text Domain: inexio.jp
Copyright 2019 inexio@Takahiro (email : dev@inexio.jp)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if ( ! defined( 'ABSPATH' ) ) { exit; }

if ( ! class_exists( 'InxEasyBannerLink' ) ) :
class InxEasyBannerLink extends WP_Widget {

  // prefix
  public $prefix = 'inx_';

  // table
  public $tbl_banner;

  // image save directory
  public $save_dir_name = 'inx-banner';

  public $db_ver_name = 'inx_easybanner_version';
  public $db_ver = "1.0.20";

  public $plg_name = 'Easy Banner Link';

  private $widget_ops;
  private $control_ops;
  private $args;
  private $instance;

  /**
   * @name __construct
   */
  public function __construct() {
    global $wpdb;

    $this->tbl_banner  = $wpdb->prefix . $this->prefix . 'banner';

    // active plugin
    register_activation_hook( __FILE__, array( $this, 'sys_activate') );

    // shortcode
    add_shortcode( 'inx-easy-banner-link', array( &$this, 'out_short_code' ) );

    // widget
    add_action( 'widgets_init', array( $this, 'add_widgets' ) );

    $this->widget_ops = array('description' => 'バナー設定で登録したバナーを表示');
    $this->control_ops = array('width' => '400', 'height' => '350');
    parent::__construct(
      false,
      $this->plg_name,
      $this->widget_ops,
      $this->control_ops
    );
  }

  /**
   * @name add_widgets
   */
  public function add_widgets() {
    register_widget( 'InxEasyBannerLink' );
    add_action( 'admin_menu', array( $this, 'add_pages' ) );
  }

  public function widget( $args, $instance ) {
    $this->args = $args;
    $this->instance = $instance;

    echo $this->get_html();
  }

  /**
   * @name add_pages
   */
  public function add_pages() {
    add_menu_page( 'バナー設定', 'バナー設定', 'level_8', __FILE__, array( $this, 'page_banner' ), '', 27 );
  }

  /**
   * @name sys_activate
   */
  public function sys_activate() {
    global $wpdb;

    $installed_var = get_option( $this->db_ver_name );
    $wp_upload_dir = wp_upload_dir();

    if ( ! file_exists( $wp_upload_dir["basedir"] ) ) {
      wp_mkdir_p($wp_upload_dir["basedir"]);
      wp_mkdir_p($wp_upload_dir["basedir"] . "/" . $this->save_dir_name . "/");
    }

    if ( ! file_exists( $wp_upload_dir["basedir"] . '/' . $this->save_dir_name . '/' ) ) {
      wp_mkdir_p($wp_upload_dir["basedir"] . "/" . $this->save_dir_name . "/");
    }

    if( $installed_var != $this->db_ver ) {
      if ( $wpdb->get_var("show tables like '$this->tbl_banner'") != $this->tbl_banner ) {
        $sql = "CREATE TABLE $this->tbl_banner (
            banner_id bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT,
            banner_name text,
            banner_img text,
            target int(11) DEFAULT 0,
            sort int(11),
            url text,
            UNIQUE KEY banner_id(banner_id)
            )
            CHARACTER SET 'utf8';";
        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta( $sql );
      }
      else {
        $sql = "CREATE TABLE $this->tbl_banner (
            banner_id bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT,
            banner_name text,
            banner_img text,
            target int(11) DEFAULT 0,
            sort int(11),
            url text,
            UNIQUE KEY banner_id(banner_id)
            )
            CHARACTER SET 'utf8';";
        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta( $sql );
      }
      update_option( $this->db_ver_name, $this->db_ver );
    }
  }

  /**
   * @name get_banner_sort_next_id
   * @desc 最後のソート番号取得
   * @return number
   */
  public function get_banner_sort_next_id() {
    global $wpdb;

    $now_sort = $wpdb->get_var(
        $wpdb->prepare(
            "SELECT sort FROM $this->tbl_banner ORDER BY sort DESC LIMIT %d",
            1
            )
        );
    $next_sort = $now_sort + 1;
    return $next_sort;
  }

  /**
   * @name sort_data
   */
  public function sort_data( $target_id = null ) {
    global $wpdb;

    $results = $wpdb->get_results(
        $wpdb->prepare(
            "SELECT * FROM $this->tbl_banner WHERE 1=%d ORDER BY sort", 1 ) );

    if ( !empty( $results ) ) {
      // データ場ある場合はソートし直す
      $update_arr = array();
      $loop = 1;
      foreach ( $results as $result ) {
        $update_arr[$loop] = $result->banner_id;
        $loop++;
      }

      foreach ( $update_arr as $sort => $banner_id ) {
        $wpdb->update( $this->tbl_banner,
            array( 'sort' => $sort ),
            array( 'banner_id' => $banner_id ),
            array( '%d', '%d' ) );
      }
    }
  }

  public function rename_imgfile( $upload_files, $mode = "add" ) {
    global $wpdb;

    $wp_upload_dir = wp_upload_dir();

    if ( isset( $upload_files['error'] ) && $upload_files['error'] === 0 ) {
      if ( validate_file($upload_files['name'] !== 0) ) {
        return array(
          'result' => -1,
          'error' => 'ファイルにエラーがありました。',
        );
      }
      else {
        $path_info = pathinfo($upload_files['name']);
        if ( ! preg_match("/\A(JPG|jpg|JPEG|jpeg|PNG|png|GIF|gif)\z/u", $path_info['extension']) ) {
          return array(
            'result' => -1,
            'error' => 'ファイルにエラーがありました。',
          );
        }
        else {
          $ext = strtolower( $path_info['extension'] );
          $filename = date("Ymd-His") . "." . $ext;

          $upload_dir = $wp_upload_dir["basedir"] . "/" . $this->save_dir_name . "/";
          move_uploaded_file( $upload_files['tmp_name'], $upload_dir . $filename );

          $banner_name = $upload_dir . $filename;
          $banner_img = $wp_upload_dir['baseurl'] . '/' . $this->save_dir_name . '/' . $filename;

          return array(
            'result' => 1,
            'error' => '',
            'banner_name' => $banner_name,
            'banner_img' => $banner_img,
          );
        }
      }
    }
    else {
      if ( preg_match("/\A(add)\z/u", $mode) ) {
        return array(
          'result' => -1,
          'error' => 'バナーをご入力ください。',
        );
      }
      else {
        return array(
          'result' => 0,
          'error' => '',
        );
      }
    }
  }

  /**
   * @name page_banner
   * @desc 設定画面
   */
  public function page_banner() {

    global $wpdb;

    $e = new WP_Error();

    /////////////////////////////////
    // 登録処理
    /////////////////////////////////
    if ( isset( $_POST['inx-banner-form-add-key'] ) && $_POST['inx-banner-form-add-key'] ) {
      if ( check_admin_referer( 'inx-banner-form-add-key-nonce', 'inx-banner-form-add-key' ) ) {

        $sort = isset( $_POST['inx-banner-sort'] ) ? sanitize_text_field( $_POST['inx-banner-sort'] ) : '';
        $url = isset( $_POST['inx-banner-url'] ) ? esc_url_raw( $_POST['inx-banner-url'] ) : '';
        $target = isset( $_POST['inx-banner-target'] ) ? sanitize_text_field( $_POST['inx-banner-target'] ) : '';

        // 次のソート番号
        $next_sort = $this->get_banner_sort_next_id();

        if ( !preg_match( "/\A[1-9][0-9]*\z/u", $sort ) ) {
          $sort = $next_sort;
        }

        if (preg_match("/\A(on)\z/u", $target)) {
          $target = 1;
        }
        else {
          $target = 0;
        }

        $res_arr = $this->rename_imgfile($_FILES['inx-banner-name']);

        if ( $res_arr['result'] === 1 ) {
          $data = array(
            'banner_name' => $res_arr['banner_name'],
            'banner_img' => $res_arr['banner_img'],
            'sort' => $sort,
            'url' => $url,
            'target' => $target,
          );

          $format = array(
            '%s',
            '%s',
            '%d',
            '%s',
            '%d'
          );

          $wpdb->insert( $this->tbl_banner, $data, $format );
          $insert_id = 0;
          $results = $wpdb->get_results(
            $wpdb->prepare(
              "SELECT * FROM $this->tbl_banner WHERE 1=%d ORDER BY banner_id DESC LIMIT 1", 1 ) );
          if ( ! empty($results) ) {
            foreach ( $results as $result ) {
              $insert_id = $result->banner_id;
            }
          }

          $updateArr = array();
          $results = $wpdb->get_results(
            $wpdb->prepare(
              "SELECT * FROM $this->tbl_banner WHERE 1=%d ORDER BY sort ASC", 1 ) );
          if ( ! empty($results) ) {
            foreach ( $results as $result ) {
              if ( (int)$insert_id != (int)$result->banner_id ) {
                if ( (int)$result->sort >= (int)$sort ) {
                  $updateArr[$result->banner_id] = ($result->sort + 1);
                }
              }
            }
          }

          if ( ! empty($updateArr) ) {
            foreach ( $updateArr as $target_id => $target_sort ) {
              $wpdb->update($this->tbl_banner,
                array('sort' => $target_sort),
                array('banner_id' => $target_id),
                array('%d', '%d'),
              );
            }
          }

          $this->sort_data();

          $e->add(
            'success',
            'バナーを追加しました。' );
          set_transient(
            'inx-banner-updates',
            $e->get_error_message( 'success' ),
            2 );
        }
        else {
          $e->add(
            'error',
            $res_arr['error'] );
          set_transient(
            'inx-banner-errors',
            $e->get_error_message( 'error' ),
            2 );
        }

        wp_safe_redirect( menu_page_url( 'inx-banner-form-add-key', false) );
      }
    }

    /////////////////////////////////
    // 更新・削除処理
    /////////////////////////////////
    if ( isset( $_POST['inx-banner-form-cnf-key'] ) && $_POST['inx-banner-form-cnf-key'] ) {
      if ( check_admin_referer( 'inx-banner-form-cnf-key-nonce', 'inx-banner-form-cnf-key' ) ) {

        $banner_id = isset( $_POST['banner_id'] ) ? sanitize_text_field( $_POST['banner_id'] ) : '';
        $sort = isset( $_POST['sort'] ) ? sanitize_text_field( $_POST['sort'] ) : '';
        $mode = isset( $_POST['mode'] ) ? sanitize_text_field( $_POST['mode'] ) : '';
        $url = isset( $_POST['url'] ) ? esc_url_raw( $_POST['url'] ) : '';
        $target = isset( $_POST['target'] ) ? sanitize_text_field( $_POST['target'] ) : '0';

        if ( preg_match( "/\A[1-9][0-9]*\z/u", $banner_id ) ) {
          switch ( $mode ) {
            case "btncnf": // 更新処理

              if ( ! preg_match( "/\A[1-9][0-9]*\z/u", $sort ) ) {
                $sort = $this->get_banner_sort_next_id();
              }

              if ( ! preg_match( "/\A[0-1]\z/u", $target ) ) {
                $target = 0;
              }

              $banner_name = '';

              $col_arr = array();
              $data_arr = array();

              $col_arr['sort'] = $sort;
              $col_arr['url'] = $url;
              $col_arr['target'] = $target;

              $data_arr[] = '%d';
              $data_arr[] = '%s';
              $data_arr[] = '%d';
              $data_arr[] = '%d';

              $max_sort = $this->get_banner_sort_next_id() - 1;
              if ( $max_sort <= $sort ) {
                // ソートしたい番号にすでに登録があるか（更新対象は除く）
                $results = $wpdb->get_results(
                  $wpdb->prepare(
                  "SELECT * FROM $this->tbl_banner WHERE banner_id <> %s ORDER BY sort",
                  $sort,
                  $banner_id ) );

                if ( !empty( $results ) ) {
                  // ある場合は、取得したデータのソート番号をそれぞれインクリメントして、データを更新する
                  $update_arr = array();
                  $loop = 1;
                  foreach ( $results as $result ) {
                    $update_arr[$loop] = $result->banner_id;
                    $loop++;
                  }

                  // 取得したデータのソート番号をそれぞれインクリメントして、データを更新する
                  foreach ( $update_arr as $sort => $banner_id2 ) {
                    $wpdb->update( $this->tbl_banner,
                    array( 'sort' => $sort ),
                    array( 'banner_id' => $banner_id2 ),
                    array( '%d', '%d' ) );
                  }
                }
              }
              else {
                // 現在のソート番号を取得
                $results = $wpdb->get_results(
                  $wpdb->prepare(
                    "SELECT * FROM $this->tbl_banner WHERE banner_id = %d",
                    $banner_id
                  )
                );

                $now_sort = $results[0]->sort;
                $start_sort = $sort;

                // // ソートしたい番号にすでに登録があるか（更新対象は除く）
                if ( $now_sort > $sort ) {
                  // 順位上昇
                  $results = $wpdb->get_results(
                    $wpdb->prepare(
                    "SELECT * FROM $this->tbl_banner WHERE sort >= %s AND banner_id <> %d ORDER BY sort",
                    $sort,
                    $banner_id ) );
                }
                else {
                  // 順位下降
                  $results = $wpdb->get_results(
                    $wpdb->prepare(
                    "SELECT * FROM $this->tbl_banner WHERE sort > %s AND banner_id <> %d ORDER BY sort",
                    $sort,
                    $banner_id ) );
                  ++$start_sort;
                }

                if ( ! empty( $results ) ) {
                  // ある場合は、取得したデータのソート番号をそれぞれインクリメントして、データを更新する
                  $update_arr = array();
                  // $loop = $sort + 1;
                  $loop = $start_sort + 1;
                  foreach ( $results as $result ) {
                    $update_arr[$loop] = $result->banner_id;
                    $loop++;
                  }

                  // 取得したデータのソート番号をそれぞれインクリメントして、データを更新する
                  foreach ( $update_arr as $sort => $banner_id2 ) {
                    $wpdb->update( $this->tbl_banner,
                    array( 'sort' => $sort ),
                    array( 'banner_id' => $banner_id2 ),
                    array( '%d', '%d' ) );
                  }
                }
              }

              $wpdb->update(
                $this->tbl_banner,
                $col_arr,
                array(
                  'banner_id' => $banner_id
                ),
                $data_arr
              );

              $this->sort_data();

              $e->add(
                'success',
                'バナーを更新しました。'
              );

              break;

            case "btndel": // 削除処理
              $wpdb->delete(
                $this->tbl_banner,
                array(
                  'banner_id' => $banner_id
                ),
                array(
                  '%d'
                )
              );

              $this->sort_data();

              $e->add(
                'success',
                'バナーを削除しました。'
              );
              break;

            default:
              break;
          }

          set_transient(
          'inx-banner-updates',
          $e->get_error_message( 'success' ),
          2 );
        }
        else {
          $e->add(
              'error',
              'エラーが発生しました。'
          );
          set_transient(
          'inx-banner-errors',
          $e->get_error_message( 'error' ),
          2 );
        }
      }

      wp_safe_redirect( menu_page_url( 'inx-banner-form-cnf-key', false ) );
    }

    $results = $wpdb->get_results(
        $wpdb->prepare(
            "SELECT * FROM $this->tbl_banner WHERE 1=%d ORDER BY sort ASC", 1 ) );
?>
<div class="wrap">

<?php if ( $messages = get_transient( "inx-banner-errors" ) ) : ?>
  <div class="error">
    <ul>
      <li><?php echo esc_html( $messages ); ?></li>
    </ul>
  </div>
<?php endif; ?>

<?php if ( $messages = get_transient( "inx-banner-updates" ) ) : ?>
  <div class="updated">
    <ul>
      <li><?php echo esc_html( $messages ); ?></li>
    </ul>
  </div>
<?php endif; ?>

  <h2>バナー画像設定</h2>
  <p style="margin-bottom:2.5rem;">
    利用方法はアイネクシオのサイトなどをご覧ください。
    <a href="https://inexio.jp/results/inx-easy-banner-link/" target="_blank">Easy Banner Link</a></p>

<style type="text/css">
.input-sort {
width: 50px;
}
.wp-editor-area {
height: 48px;
width: 360px;
}
</style>
<script>

document.addEventListener('DOMContentLoaded', function(){
  var inx_btn_del = document.getElementsByClassName('inx-btn-del');
  var inx_btn_dels = Array.from(inx_btn_del);
  var inx_btn_cnf = document.getElementsByClassName('inx-btn-cnf');
  var inx_btn_cnfs = Array.from(inx_btn_cnf);

  inx_btn_dels.forEach(function(target){
    target.addEventListener('click', function(){
      var btnArr = this.id.split('_');
      var banner_id = btnArr[1];
      var mode = btnArr[0];

      if ( !banner_id.match(/^[1-9][0-9]*$/g) ) {
        return false;
      }

      if ( !mode.match(/^(btndel)$/g) ) {
        return false;
      }

      if ( !confirm( "削除しますが、本当によろしいでしょうか？" ) ) {
        return false;
      }

      var sortObj = document.getElementById("sort_" + banner_id);
      var sort = sortObj.value;
      var urlObj = document.getElementById("url_" + banner_id);
      var url = urlObj.value;

      document.getElementById("send_banner_id").value = banner_id;
      document.getElementById("send_mode").value = mode;
      document.getElementById("send_sort").value = sort;
      document.getElementById("send_url").value = url;
      document.getElementById("send_target").value = 0;

      document.getElementById("inx-banner-form-cnf").submit();
      return;
    });
  });

  inx_btn_cnfs.forEach(function(target){
    target.addEventListener('click', function(){
      var btnArr = this.id.split('_');
      var banner_id = btnArr[1];
      var mode = btnArr[0];
      if ( !banner_id.match(/^[1-9][0-9]*$/g) ) {
        return false;
      }

      if ( !mode.match(/^(btncnf)$/g) ) {
        return false;
      }

      var sortObj = document.getElementById("sort_" + banner_id);
      var sort = sortObj.value;
      var urlObj = document.getElementById("url_" + banner_id);
      var url = urlObj.value;
      var targetObj = document.getElementById("target_" + banner_id);
      var target = targetObj.checked;
      if (target === true) {
        target = 1;
      }
      else {
        target = 0;
      }

      document.getElementById("send_banner_id").value = banner_id;
      document.getElementById("send_mode").value = mode;
      document.getElementById("send_sort").value = sort;
      document.getElementById("send_url").value = url;
      document.getElementById("send_target").value = target;

      document.getElementById("inx-banner-form-cnf").submit();
      return;
    });
  });
});
</script>

  <div style="margin-bottom:3.0em;">
  <form id="inx-banner-form-add" action="" method="post" enctype="multipart/form-data">
    <?php wp_nonce_field( 'inx-banner-form-add-key-nonce', 'inx-banner-form-add-key' ); ?>
    <h3>バナー追加</h3>
    <p>以下へ情報を入力して、バナー画像を登録することができます。<br />順番を入力しない場合は、バナーの一番最後に出力されます。</p>
    <table class="wp-list-table widefat plugins">
      <thead>
        <tr class="inactive">
          <th>バナー名</th>
          <th>URL</th>
          <th>新規タブ</th>
          <th>順番</th>
          <th>操作</th>
        </tr>
      </thead>
      <tbody>
        <tr class="inactive">
          <td>
            <input type="file" name="inx-banner-name" />
          </td>
          <td>
            <input type="text" name="inx-banner-url" style="width:80%;">
          </td>
          <td style="vertical-align:middle;">
            <input type="checkbox" name="inx-banner-target">
          </td>
          <td style="vertical-align:middle;">
            <input type="text" class="input-sort" name="inx-banner-sort" value="" /></td>
          <td style="vertical-align:middle;">
            <p class="submit">
              <input type="submit" value="追加" class="button button-primary button-small" ></p></td>
        </tr>
      </tbody>
    </table>
  </form>
  </div>

  <form id="inx-banner-form-cnf" action="" method="post" enctype="multipart/form-data">
    <?php wp_nonce_field( 'inx-banner-form-cnf-key-nonce', 'inx-banner-form-cnf-key' ); ?>
    <input type="hidden" id="send_banner_id" name="banner_id" value="" />
    <input type="hidden" id="send_url" name="url" value="" />
    <input type="hidden" id="send_target" name="target" value="" />
    <input type="hidden" id="send_sort" name="sort" value="" />
    <input type="hidden" id="send_mode" name="mode" value="" />
    <h3>登録済みバナー一覧</h3>
    <p>登録済みの画像を更新したい場合は、画像を削除していただき、新規登録を行ってください。</p>
    <?php if ( !empty( $results ) ) : ?>
    <table class="wp-list-table widefat plugins">
      <thead>
        <tr class="inactive">
          <th>バナー画像</th>
          <th>URL</th>
          <th>新規タブ</th>
          <th>順番</th>
          <th>操作</th>
        </tr>
      </thead>
      <tbody id="the-list">
      <?php foreach ( $results as $result ) : ?>
        <tr class="inactive">
          <td>
            <img src="<?php echo $result->banner_img; ?>" width="250" alt="イメージ" />
          </td>
          <td style="vertical-align:middle;">
            <input type="text" id="url_<?php echo esc_html($result->banner_id); ?>" class="input-url" value="<?php echo esc_html($result->url); ?>" style="width:80%;">
          </td>
          <td style="vertical-align:middle;">
            <input type="checkbox" id="target_<?php echo esc_html($result->banner_id); ?>" class="" name="inx-banner-target"<?php echo (isset($result->target)&&(int)$result->target===1)?' checked="checked"':'';?>>
          </td>
          <td style="vertical-align:middle;">
            <input type="text" id="sort_<?php echo esc_html($result->banner_id); ?>" class="input-sort" value="<?php echo esc_html($result->sort); ?>" />
          </td>
          <td style="vertical-align:middle;">
            <p class="submit">
              <input type="button" id="btndel_<?php echo esc_html($result->banner_id); ?>" value="削除" class="inx-btn inx-btn-del button button-primary button-small">
              <input type="button" id="btncnf_<?php echo esc_html($result->banner_id); ?>" value="更新" class="inx-btn inx-btn-cnf button button-primary button-small">
            </p>
          </td>
        </tr>
      <?php endforeach; ?>
      </tbody>
    </table>
    <?php else : ?>
    <p>只今登録されているバナーはありません。</p>
    <?php endif; ?>
  </form>
</div><!-- /.wrap -->
<?php
  }

  /**
   * @name out_short_code
   * @desc ショートコード用データ出力
   * @param array $atts
   */
  public function out_short_code( $atts ) {
    global $wpdb;

    $data_arr = $wpdb->get_results(
      $wpdb->prepare(
        "SELECT * FROM $this->tbl_banner WHERE 1=%d ORDER BY sort", 1 ) );

    $out_result = '';
    if ( ! empty( $data_arr ) ) {
      $a_class = isset($atts['a-class']) ? $atts['a-class'] : '';
      $img_class = isset($atts['img-class']) ? $atts['img-class'] : '';

      $parent_tag = 'ul';
      if (isset($atts['parent-tag'])) {
        if (empty($atts['parent-tag'])) {
          $parent_tag = '';
        }
        else {
          $parent_tag = $atts['parent-tag'];
        }
      }

      $child_tag = 'li';
      if (isset($atts['child-tag'])) {
        if (empty($atts['child-tag'])) {
          $child_tag = '';
        }
        else {
          $child_tag = $atts['child-tag'];
        }
      }

      $parent_class = isset($atts['parent-class']) ? $atts['parent-class'] : '';
      $child_class = isset($atts['child-class']) ? $atts['child-class'] : '';

      foreach ( $data_arr as $num => $arr ) {
        $link_arr = array("", "");
        if ( ! empty( $arr->url ) ) {
          $a_target = '';
          if ($arr->target > 0) {
            $a_target = ' target="_blank"';
          }
          $link_arr[0] = '<a class="' . $a_class . '" href="' . $arr->url . '"' . $a_target . '>';
          $link_arr[1] = '</a>';
        }

        if (empty($child_tag)) {
          $out_result .= $link_arr[0];
          $out_result .= '<img class="' . $img_class . '" src="' . $arr->banner_img . '" />';
          $out_result .= $link_arr[1];
        }
        else {
          $out_result .= '<' . $child_tag . ' class="' . $child_class . '">';
          $out_result .= $link_arr[0];
          $out_result .= '<img class="' . $img_class . '" src="' . $arr->banner_img . '" />';
          $out_result .= $link_arr[1];
          $out_result .= '</' . $child_tag . '>';
        }
      }

      if (empty($parent_tag)) {
        $out_result = $out_result;
      }
      else {
        $out_result = '<' . $parent_tag . ' class="' . $parent_class . '">' . $out_result . '</' . $parent_tag . '>';
      }
    }

    return $out_result;
  }

  /**
   * @name get_list
   * @desc 登録済みバナーリストを返す
   */
  public function get_list( $orders = "ASC", $limit = 5 ) {
    global $wpdb;

    $sql = $wpdb->prepare(
        "SELECT * FROM $this->tbl_banner ORDER BY sort " . $orders . " LIMIT %d ", $limit );
    $data_arr = $wpdb->get_results($sql);

    return $data_arr;
  }

  /**
   * @name get_html
   * @desc 登録済みバナーリストを返す
   */
  // public function get_html( $a_class = "", $img_class = "", $parent_tag = "ul", $child_tag = "li", $parent_class = "", $child_class = "", $target = '', $orders = "ASC", $limit = 5 ) {
  public function get_html( $atts ) {
    global $wpdb;

    $limit = 50;
    $orders = "ASC";

    $sql = $wpdb->prepare(
        "SELECT * FROM $this->tbl_banner ORDER BY sort " . $orders . " LIMIT %d ",
        $limit );
    $data_arr = $wpdb->get_results($sql);

    if ( ! empty( $data_arr ) ) {
      $a_class = isset($atts['a-class']) ? $atts['a-class'] : '';
      $img_class = isset($atts['img-class']) ? $atts['img-class'] : '';

      $parent_tag = 'ul';
      if (isset($atts['parent-tag'])) {
        if (empty($atts['parent-tag'])) {
          $parent_tag = '';
        }
        else {
          $parent_tag = $atts['parent-tag'];
        }
      }
      else {
        $parent_tag = 'ul';
      }

      $child_tag = 'li';
      if (isset($atts['child-tag'])) {
        if (empty($atts['child-tag'])) {
          $child_tag = '';
        }
        else {
          $child_tag = $atts['child-tag'];
        }
      }
      else {
        $child_tag = 'li';
      }

      $parent_class = isset($atts['parent-class']) ? $atts['parent-class'] : '';
      $child_class = isset($atts['child-class']) ? $atts['child-class'] : '';

      $a_target = isset($atts['target']) ? ' target="_blank"' : '';

      foreach ( $data_arr as $num => $arr ) {
        $link_arr = array("", "");
        if ( ! empty( $arr->url ) ) {
          $a_target = '';
          if ($arr->target > 0) {
            $a_target = ' target="_blank"';
          }
          $link_arr[0] = '<a class="' . $a_class . '" href="' . $arr->url . '"' . $a_target . '>';
          $link_arr[1] = '</a>';
        }

        if (empty($child_tag)) {
          $out_result .= $link_arr[0];
          $out_result .= '<img class="' . $img_class . '" src="' . $arr->banner_img . '" />';
          $out_result .= $link_arr[1];
        }
        else {
          $out_result .= '<' . $child_tag . ' class="' . $child_class . '">';
          $out_result .= $link_arr[0];
          $out_result .= '<img class="' . $img_class . '" src="' . $arr->banner_img . '" />';
          $out_result .= $link_arr[1];
          $out_result .= '</' . $child_tag . '>';
        }
      }

      if (empty($parent_tag)) {
        $out_result = $out_result;
      }
      else {
        $out_result = '<' . $parent_tag . ' class="' . $parent_class . '">'
              . $out_result
              . '</' . $parent_tag . '>';
      }
    }

    return $out_result;
  }
}

$InxEasyBannerLink = new InxEasyBannerLink;

endif; //end class
